﻿using Microsoft.SmallBasic.Library;

namespace SBAliases
{
    /// <summary>
    /// The Shape object allows you to add, move and rotate shapes to the Graphics window.
    /// </summary>
    [SmallBasicType]
    public static class _Shapes
    {
        /// <summary>
        /// Adds a rectangle shape with the specified width and height.
        /// </summary>
        /// <param name="width">The width of the rectangle shape.</param>
        /// <param name="height">The height of the rectangle shape.</param>
        /// <returns>
        /// The Rectangle shape that was just added to the Graphics Window.
        /// </returns>
        public static Primitive AddRectangle(Primitive width, Primitive height)
        {
            return Shapes.AddRectangle(width, height);
        }

        /// <summary>
        /// Adds an ellipse shape with the specified width and height.
        /// </summary>
        /// <param name="width">The width of the ellipse shape.</param>
        /// <param name="height">The height of the ellipse shape.</param>
        /// <returns>
        /// The Ellipse shape that was just added to the Graphics Window.
        /// </returns>
        public static Primitive AddEllipse(Primitive width, Primitive height)
        {
            return Shapes.AddEllipse(width, height);
        }

        /// <summary>
        /// Adds a triangle shape represented by the specified points.
        /// </summary>
        /// <param name="x1">The x co-ordinate of the first point.</param>
        /// <param name="y1">The y co-ordinate of the first point.</param>
        /// <param name="x2">The x co-ordinate of the second point.</param>
        /// <param name="y2">The y co-ordinate of the second point.</param>
        /// <param name="x3">The x co-ordinate of the third point.</param>
        /// <param name="y3">The y co-ordinate of the third point.</param>
        /// <returns>
        /// The Triangle shape that was just added to the Graphics Window.
        /// </returns>
        public static Primitive AddTriangle(
          Primitive x1,
          Primitive y1,
          Primitive x2,
          Primitive y2,
          Primitive x3,
          Primitive y3)
        {
            return Shapes.AddTriangle(x1, y1, x2, y2, x3, y3);
        }

        /// <summary>Adds a line between the specified points.</summary>
        /// <param name="x1">The x co-ordinate of the first point.</param>
        /// <param name="y1">The y co-ordinate of the first point.</param>
        /// <param name="x2">The x co-ordinate of the second point.</param>
        /// <param name="y2">The y co-ordinate of the second point.</param>
        /// <returns>The line that was just added to the Graphics Window.</returns>
        public static Primitive AddLine(Primitive x1, Primitive y1, Primitive x2, Primitive y2)
        {
            return Shapes.AddLine(x1, y1, x2, y2);
        }

        /// <summary>
        /// Adds an image as a shape that can be moved, animated or rotated.
        /// </summary>
        /// <param name="imageName">The name of the image to draw.</param>
        /// <returns>The image that was just added to the Graphics Window.</returns>
        public static Primitive AddImage(Primitive imageName)
        {
            return Shapes.AddImage(imageName);
        }

        /// <summary>
        /// Adds some text as a shape that can be moved, animated or rotated.
        /// </summary>
        /// <param name="text">The text to add.</param>
        /// <returns>
        /// The text shape that was just added to the Graphics Window.
        /// </returns>
        public static Primitive AddText(Primitive text)
        {
            return Shapes.AddText(text);
        }

        /// <summary>Sets the text of a text shape.</summary>
        /// <param name="shapeName">The name of the text shape.</param>
        /// <param name="text">The new text value to set.</param>
        public static void SetText(Primitive shapeName, Primitive text)
        {
            Shapes.SetText(shapeName, text);
        }

        /// <summary>Removes a shape from the Graphics Window.</summary>
        /// <param name="shapeName">
        /// The name of the shape that needs to be removed.
        /// </param>
        public static void Remove(Primitive shapeName)
        {
            Shapes.Remove(shapeName);
        }

        /// <summary>
        /// Moves the shape with the specified name to a new position.
        /// </summary>
        /// <param name="shapeName">The name of the shape to move.</param>
        /// <param name="x">The x co-ordinate of the new position.</param>
        /// <param name="y">The y co-ordinate of the new position.</param>
        public static void Move(Primitive shapeName, Primitive x, Primitive y)
        {
            Shapes.Move(shapeName, x, y);
        }

        /// <summary>
        /// Rotates the shape with the specified name to the specified angle.
        /// </summary>
        /// <param name="shapeName">The name of the shape to rotate.</param>
        /// <param name="angle">The angle to rotate the shape.</param>
        public static void Rotate(Primitive shapeName, Primitive angle)
        {
            Shapes.Rotate(shapeName, angle);
        }

        /// <summary>
        /// Scales the shape using the specified zoom levels.  Minimum is 0.1 and maximum is 20.
        /// </summary>
        /// <param name="shapeName">The name of the shape to zoom.</param>
        /// <param name="scaleX">The x-axis zoom level.</param>
        /// <param name="scaleY">The y-axis zoom level.</param>
        public static void Zoom(Primitive shapeName, Primitive scaleX, Primitive scaleY)
        {
            Shapes.Zoom(shapeName, scaleX, scaleY);
        }

        /// <summary>
        /// Animates a shape with the specified name to a new position.
        /// </summary>
        /// <param name="shapeName">The name of the shape to move.</param>
        /// <param name="x">The x co-ordinate of the new position.</param>
        /// <param name="y">The y co-ordinate of the new position.</param>
        /// <param name="duration">
        /// The time for the animation, in milliseconds.
        /// </param>
        public static void Animate(Primitive shapeName, Primitive x, Primitive y, Primitive duration)
        {
            Shapes.Animate(shapeName, x, y, duration);
        }

        /// <summary>Gets the left co-ordinate of the specified shape.</summary>
        /// <param name="shapeName">The name of the shape.</param>
        /// <returns>The left co-ordinate of the shape.</returns>
        public static Primitive GetLeft(Primitive shapeName)
        {
            return Shapes.GetLeft(shapeName);
        }

        /// <summary>Gets the top co-ordinate of the specified shape.</summary>
        /// <param name="shapeName">The name of the shape.</param>
        /// <returns>The top co-ordinate of the shape.</returns>
        public static Primitive GetTop(Primitive shapeName)
        {
            return Shapes.GetTop(shapeName);
        }

        /// <summary>Gets the opacity of a shape.</summary>
        /// <param name="shapeName">The name of the shape.</param>
        /// <returns>
        /// The opacity of the object as a value between 0 and 100.  0 is completely transparent and 100 is completely opaque.
        /// </returns>
        public static Primitive GetOpacity(Primitive shapeName)
        {
            return Shapes.GetOpacity(shapeName);
        }

        /// <summary>Sets how opaque a shape should render.</summary>
        /// <param name="shapeName">The name of the shape.</param>
        /// <param name="level">
        /// The opacity level ranging from 0 to 100.  0 is completely transparent and 100 is completely opaque.
        /// </param>
        public static void SetOpacity(Primitive shapeName, Primitive level)
        {
            Shapes.SetOpacity(shapeName, level);
        }

        /// <summary>Hides an already added shape.</summary>
        /// <param name="shapeName">The name of the shape.</param>
        public static void HideShape(Primitive shapeName)
        {
            Shapes.HideShape(shapeName);
        }

        /// <summary>Shows a previously hidden shape.</summary>
        /// <param name="shapeName">The name of the shape.</param>
        public static void ShowShape(Primitive shapeName)
        {
            Shapes.ShowShape(shapeName);
        }
    }
}
